==> business_central_kon-0.4.0.tar.gz: business_central_kon-0.4.0/src/business_central_kon/services.py <==
import pandas as pd

from .session import BusinessCentralSession


class BaseService:
    """
    Base class for interacting with Business Central API endpoints.
    Each subclass should define the SERVICE_NAME for the respective API endpoint.
    """

    SERVICE_NAME = ""

    def __init__(self, session: BusinessCentralSession) -> None:
        """
        Initialize the service with a session.
        :param session: An instance of BusinessCentralSession.
        """

        if not self.SERVICE_NAME:
            raise ValueError("SERVICE_NAME must be defined in the subclass.")
        self.session = session

    def get_data(self, filters: str = "", columns: dict = None, as_dataframe: bool = False) -> list | pd.DataFrame:
        """
        Fetch data from the API endpoint with optional filters and column selection.
        :param filters: OData filter string for query conditions.
        :param columns: Dict of column names to select.
        :param as_dataframe: Return results as a pandas DataFrame if True, otherwise as a list.
        :return: List or DataFrame of fetched data.
        """

        return self.session.fetch_data(
            service_name=self.SERVICE_NAME,
            filters=filters, columns=columns,
            as_dataframe=as_dataframe
        )


class CustomerService(BaseService):
    SERVICE_NAME = "customers_list"


class CustomerLedgerEntryService(BaseService):
    SERVICE_NAME = "Customer_Ledger_entry_API"


class VendorService(BaseService):
    SERVICE_NAME = "vendors"


class VendorLedgerEntryService(BaseService):
    SERVICE_NAME = "VendorLedgerEntries"


class ItemService(BaseService):
    SERVICE_NAME = "items_list"


class ItemLedgerEntryService(BaseService):
    SERVICE_NAME = "ILE_Consumption"


class GeneralLedgerService(BaseService):
    SERVICE_NAME = "Chart_of_Accounts"


class GeneralLedgerEntriesService(BaseService):
    SERVICE_NAME = "gl_entries"


class SalesInvoiceService(BaseService):
    SERVICE_NAME = "PostedSalesInvoice"


class SalesInvoiceLinesService(BaseService):
    SERVICE_NAME = "posted_sales_invoice_lines"


class ILEOriginEntriesService(BaseService):
    SERVICE_NAME = "ile_origin_detail"


class SalesOrderLinesService(BaseService):
    SERVICE_NAME = "sales_lines"


class LocationService(BaseService):
    SERVICE_NAME = "locations_master"


class BomHeaderService(BaseService):
    SERVICE_NAME = "ProductionBOMHeader"


class BomLinesService(BaseService):
    SERVICE_NAME = "ProductionBOMLines"

==> business_central_kon-0.5.0.tar.gz: business_central_kon-0.5.0/src/business_central_kon/services.py <==
import pandas as pd

from .session import BusinessCentralSession


class BaseService:
    """
    Base class for interacting with Business Central API endpoints.
    Each subclass should define the SERVICE_NAME for the respective API endpoint.
    """

    SERVICE_NAME = ""

    def __init__(self, session: BusinessCentralSession) -> None:
        """
        Initialize the service with a session.
        :param session: An instance of BusinessCentralSession.
        """

        if not self.SERVICE_NAME:
            raise ValueError("SERVICE_NAME must be defined in the subclass.")
        self.session = session

    def get_data(self, filters: str = "", columns: dict = None, as_dataframe: bool = False) -> list | pd.DataFrame:
        """
        Fetch data from the API endpoint with optional filters and column selection.
        :param filters: OData filter string for query conditions.
        :param columns: Dict of column names to select.
        :param as_dataframe: Return results as a pandas DataFrame if True, otherwise as a list.
        :return: List or DataFrame of fetched data.
        """

        return self.session.fetch_data(
            service_name=self.SERVICE_NAME,
            filters=filters, columns=columns,
            as_dataframe=as_dataframe
        )

    def get_top_ten(self, as_dataframe: bool = False) -> list | pd.DataFrame:
        """
        Fetch the top 10 records from the API endpoint without any filters or column selection.
        :param as_dataframe: Return results as a pandas DataFrame if True, otherwise as a list.
        :return: List or DataFrame of the top 10 records.
        """
        # Construct the URL with $top=10
        url = self.session._build_query_url(service_name=self.SERVICE_NAME)
        url = f"{url}?$top=10"

        # Fetch data directly
        data = self.session._fetch_paginated_data(url)

        if as_dataframe:
            return self.session._convert_to_dataframe(data)

        return data


class CustomerService(BaseService):
    SERVICE_NAME = "ksppl_customers"


class CustomerLedgerEntryService(BaseService):
    SERVICE_NAME = "ksppl_customer_ledger_entries"


class VendorService(BaseService):
    SERVICE_NAME = "ksppl_vendors"


class VendorLedgerEntryService(BaseService):
    SERVICE_NAME = "ksppl_vendor_ledger_entries"


class ItemService(BaseService):
    SERVICE_NAME = "ksppl_items"


class ItemLedgerEntryService(BaseService):
    SERVICE_NAME = "ksppl_item_ledger_entries"


class GeneralLedgerService(BaseService):
    SERVICE_NAME = "ksppl_general_ledgers"


class GeneralLedgerEntriesService(BaseService):
    SERVICE_NAME = "ksppl_general_ledger_entries"


class SalesInvoiceService(BaseService):
    SERVICE_NAME = "ksppl_sales_invoices"


class SalesInvoiceLinesService(BaseService):
    SERVICE_NAME = "ksppl_sales_invoice_lines"


class ILEOriginEntriesService(BaseService):
    SERVICE_NAME = "ksppl_ile_origin_detail"


class SalesOrderLinesService(BaseService):
    SERVICE_NAME = "ksppl_sales_lines"


class LocationService(BaseService):
    SERVICE_NAME = "ksppl_locations"


class BomHeaderService(BaseService):
    SERVICE_NAME = "ksppl_boms"


class BomLinesService(BaseService):
    SERVICE_NAME = "ksppl_bom_lines"
